@@ -7,7 +7,7 @@ import types
 import typing
 import traceback
 
-from mitmproxy import addonmanager
+from mitmproxy import addonmanager, hooks
 from mitmproxy import exceptions
 from mitmproxy import flow
 from mitmproxy import command
@@ -29,6 +29,7 @@ def load_script(path: str) -> typing.Optional[types.ModuleType]:
     try:
         loader = importlib.machinery.SourceFileLoader(fullname, path)
         spec = importlib.util.spec_from_loader(fullname, loader=loader)
+        assert spec
         m = importlib.util.module_from_spec(spec)
         loader.exec_module(m)
         if not getattr(m, "name", None):
@@ -104,12 +105,11 @@ class Script:
         if self.ns:
             # We're already running, so we have to explicitly register and
             # configure the addon
-            ctx.master.addons.invoke_addon(self.ns, "running")
+            ctx.master.addons.invoke_addon(self.ns, hooks.RunningHook())
             try:
                 ctx.master.addons.invoke_addon(
                     self.ns,
-                    "configure",
-                    ctx.options.keys()
+                    hooks.ConfigureHook(ctx.options.keys())
                 )
             except exceptions.OptionsError as e:
                 script_error_handler(self.fullpath, e, msg=str(e))
@@ -161,15 +161,14 @@ class ScriptLoader:
         mod = load_script(path)
         if mod:
             with addonmanager.safecall():
-                ctx.master.addons.invoke_addon(mod, "running")
+                ctx.master.addons.invoke_addon(mod, hooks.RunningHook())
                 ctx.master.addons.invoke_addon(
                     mod,
-                    "configure",
-                    ctx.options.keys()
+                    hooks.ConfigureHook(ctx.options.keys()),
                 )
                 for f in flows:
-                    for evt, arg in eventsequence.iterate(f):
-                        ctx.master.addons.invoke_addon(mod, evt, arg)
+                    for evt in eventsequence.iterate(f):
+                        ctx.master.addons.invoke_addon(mod, evt)
 
     def configure(self, updated):
         if "scripts" in updated:
@@ -210,4 +209,4 @@ class ScriptLoader:
                 if self.is_running:
                     # If we're already running, we configure and tell the addon
                     # we're up and running.
-                    ctx.master.addons.invoke_addon(s, "running")
+                    ctx.master.addons.invoke_addon(s, hooks.RunningHook())
