@@ -1,18 +1,14 @@
-import sys
+from typing import IO, Optional
+
 import click
 
 from mitmproxy import log
 from mitmproxy import ctx
 
-# These get over-ridden by the save execution context. Keep them around so we
-# can log directly.
-realstdout = sys.stdout
-realstderr = sys.stderr
-
 
 class TermLog:
     def __init__(self, outfile=None):
-        self.outfile = outfile
+        self.outfile: Optional[IO] = outfile
 
     def load(self, loader):
         loader.add_option(
@@ -21,16 +17,11 @@ class TermLog:
             choices=log.LogTierOrder
         )
 
-    def log(self, e):
-        if log.log_tier(e.level) == log.log_tier("error"):
-            outfile = self.outfile or realstderr
-        else:
-            outfile = self.outfile or realstdout
-
+    def add_log(self, e):
         if log.log_tier(ctx.options.termlog_verbosity) >= log.log_tier(e.level):
             click.secho(
                 e.msg,
-                file=outfile,
+                file=self.outfile,
                 fg=dict(error="red", warn="yellow",
                         alert="magenta").get(e.level),
                 dim=(e.level == "debug"),
