@@ -1,11 +1,11 @@
+from typing import Optional
+
 from mitmproxy.net.http import url
-from mitmproxy.coretypes import multidict
 from . import base
 
 
 class ViewURLEncoded(base.View):
     name = "URL-encoded"
-    content_types = ["application/x-www-form-urlencoded"]
 
     def __call__(self, data, **metadata):
         try:
@@ -13,4 +13,7 @@ class ViewURLEncoded(base.View):
         except ValueError:
             return None
         d = url.decode(data)
-        return "URLEncoded form", base.format_dict(multidict.MultiDict(d))
+        return "URLEncoded form", base.format_pairs(d)
+
+    def render_priority(self, data: bytes, *, content_type: Optional[str] = None, **metadata) -> float:
+        return float(content_type == "application/x-www-form-urlencoded")
