@@ -17,6 +17,12 @@ import collections.abc
 import pydivert
 import pydivert.consts
 
+if typing.TYPE_CHECKING:
+    class WindowsError(OSError):
+        @property
+        def winerror(self) -> int:
+            return 42
+
 REDIRECT_API_HOST = "127.0.0.1"
 REDIRECT_API_PORT = 8085
 
@@ -68,7 +74,7 @@ class Resolver:
                 if addr is None:
                     raise RuntimeError("Cannot resolve original destination.")
                 return tuple(addr)
-            except (EOFError, socket.error):
+            except (EOFError, OSError):
                 self._connect()
                 return self.original_addr(csock)
 
@@ -91,7 +97,7 @@ class APIRequestHandler(socketserver.StreamRequestHandler):
                     except KeyError:
                         server = None
                     write(server, self.wfile)
-        except (EOFError, socket.error):
+        except (EOFError, OSError):
             pass
 
 
