@@ -10,11 +10,11 @@ import urwid.util
 
 from mitmproxy import flow
 from mitmproxy.http import HTTPFlow
-from mitmproxy.utils import human
+from mitmproxy.utils import human, emoji
 from mitmproxy.tcp import TCPFlow
 
-# Detect Windows Subsystem for Linux
-IS_WSL = "Microsoft" in platform.platform()
+# Detect Windows Subsystem for Linux and Windows
+IS_WINDOWS = "Microsoft" in platform.platform() or "Windows" in platform.platform()
 
 
 def is_keypress(k):
@@ -119,6 +119,8 @@ else:
 SCHEME_STYLES = {
     'http': 'scheme_http',
     'https': 'scheme_https',
+    'ws': 'scheme_ws',
+    'wss': 'scheme_wss',
     'tcp': 'scheme_tcp',
 }
 HTTP_REQUEST_METHOD_STYLES = {
@@ -159,6 +161,16 @@ def fixlen_r(s: str, maxlen: int) -> str:
         return SYMBOL_ELLIPSIS + s[len(s) - maxlen + len(SYMBOL_ELLIPSIS):]
 
 
+def render_marker(marker: str) -> str:
+    rendered = emoji.emoji.get(marker, SYMBOL_MARK)
+
+    # The marker can only be one glyph. Some emoji that use zero-width joiners (ZWJ)
+    # will not be rendered as a single glyph and instead will show
+    # multiple glyphs. Just use the first glyph as a fallback.
+    # https://emojipedia.org/emoji-zwj-sequence/
+    return rendered[0]
+
+
 class TruncatedText(urwid.Widget):
     def __init__(self, text, attr, align='left'):
         self.text = text
@@ -297,12 +309,8 @@ def colorize_url(url):
     parts = url.split('/', 3)
     if len(parts) < 4 or len(parts[1]) > 0 or parts[0][-1:] != ':':
         return [('error', len(url))]  # bad URL
-    schemes = {
-        'http:': 'scheme_http',
-        'https:': 'scheme_https',
-    }
     return [
-               (schemes.get(parts[0], "scheme_other"), len(parts[0]) - 1),
+               (SCHEME_STYLES.get(parts[0], "scheme_other"), len(parts[0]) - 1),
                ('url_punctuation', 3),  # ://
            ] + colorize_host(parts[2]) + colorize_req('/' + parts[3])
 
@@ -361,18 +369,18 @@ def format_left_indicators(
 def format_right_indicators(
         *,
         replay: bool,
-        marked: bool
+        marked: str,
 ):
     indicators: typing.List[typing.Union[str, typing.Tuple[str, str]]] = []
     if replay:
         indicators.append(("replay", SYMBOL_REPLAY))
     else:
         indicators.append(" ")
-    if marked:
-        indicators.append(("mark", SYMBOL_MARK))
+    if bool(marked):
+        indicators.append(("mark", render_marker(marked)))
     else:
-        indicators.append(" ")
-    return "fixed", 2, urwid.Text(indicators)
+        indicators.append("  ")
+    return "fixed", 3, urwid.Text(indicators)
 
 
 @lru_cache(maxsize=800)
@@ -380,7 +388,7 @@ def format_http_flow_list(
         *,
         render_mode: RenderMode,
         focused: bool,
-        marked: bool,
+        marked: str,
         is_replay: bool,
         request_method: str,
         request_scheme: str,
@@ -481,7 +489,7 @@ def format_http_flow_table(
         *,
         render_mode: RenderMode,
         focused: bool,
-        marked: bool,
+        marked: str,
         is_replay: typing.Optional[str],
         request_method: str,
         request_scheme: str,
@@ -576,7 +584,7 @@ def format_http_flow_table(
 
     items.append(format_right_indicators(
         replay=bool(is_replay),
-        marked=marked
+        marked=marked,
     ))
     return urwid.Columns(items, dividechars=1, min_width=15)
 
@@ -587,7 +595,7 @@ def format_tcp_flow(
         render_mode: RenderMode,
         focused: bool,
         timestamp_start: float,
-        marked: bool,
+        marked: str,
         client_address,
         server_address,
         total_size: int,
@@ -669,7 +677,7 @@ def format_flow(
             focused=focused,
             timestamp_start=f.timestamp_start,
             marked=f.marked,
-            client_address=f.client_conn.address,
+            client_address=f.client_conn.peername,
             server_address=f.server_conn.address,
             total_size=total_size,
             duration=duration,
@@ -699,6 +707,13 @@ def format_flow(
             response_content_type = None
             duration = None
 
+        scheme = f.request.scheme
+        if f.websocket is not None:
+            if scheme == "https":
+                scheme = "wss"
+            elif scheme == "http":
+                scheme = "ws"
+
         if render_mode in (RenderMode.LIST, RenderMode.DETAILVIEW):
             render_func = format_http_flow_list
         else:
@@ -709,7 +724,7 @@ def format_flow(
             marked=f.marked,
             is_replay=f.is_replay,
             request_method=f.request.method,
-            request_scheme=f.request.scheme,
+            request_scheme=scheme,
             request_host=f.request.pretty_host if hostheader else f.request.host,
             request_path=f.request.path,
             request_url=f.request.pretty_url if hostheader else f.request.url,
