@@ -1,90 +1,79 @@
+import typing
 import urwid
 
+import mitmproxy.flow
 from mitmproxy import http
 from mitmproxy.tools.console import common, searchable
-from mitmproxy.utils import human
-from mitmproxy.utils import strutils
+from mitmproxy.utils import human, strutils
 
 
 def maybe_timestamp(base, attr):
     if base is not None and getattr(base, attr):
         return human.format_timestamp_with_milli(getattr(base, attr))
     else:
-        return "active"
+        # in mitmdump we serialize before a connection is closed.
+        # loading those flows at a later point shouldn't display "active".
+        # We also use a ndash (and not a regular dash) so that it is sorted
+        # after other timestamps. We may need to revisit that in the future if it turns out
+        # to render ugly in consoles.
+        return "–"
 
 
-def flowdetails(state, flow: http.HTTPFlow):
+def flowdetails(state, flow: mitmproxy.flow.Flow):
     text = []
 
     sc = flow.server_conn
     cc = flow.client_conn
-    req = flow.request
-    resp = flow.response
+    req: typing.Optional[http.Request]
+    resp: typing.Optional[http.Response]
+    if isinstance(flow, http.HTTPFlow):
+        req = flow.request
+        resp = flow.response
+    else:
+        req = None
+        resp = None
     metadata = flow.metadata
+    comment = flow.comment
+
+    if comment:
+        text.append(urwid.Text([("head", "Comment: "), ("text", comment)]))
 
     if metadata is not None and len(metadata) > 0:
         parts = [(str(k), repr(v)) for k, v in metadata.items()]
         text.append(urwid.Text([("head", "Metadata:")]))
         text.extend(common.format_keyvals(parts, indent=4))
 
-    if sc is not None and sc.ip_address:
+    if sc is not None and sc.peername:
         text.append(urwid.Text([("head", "Server Connection:")]))
         parts = [
             ("Address", human.format_address(sc.address)),
         ]
-        if sc.ip_address:
-            parts.append(("Resolved Address", human.format_address(sc.ip_address)))
+        if sc.peername:
+            parts.append(("Resolved Address", human.format_address(sc.peername)))
         if resp:
             parts.append(("HTTP Version", resp.http_version))
-        if sc.alpn_proto_negotiated:
-            parts.append(("ALPN", sc.alpn_proto_negotiated))
+        if sc.alpn:
+            parts.append(("ALPN", strutils.bytes_to_escaped_str(sc.alpn)))
 
         text.extend(
             common.format_keyvals(parts, indent=4)
         )
 
-        c = sc.cert
-        if c:
+        if sc.certificate_list:
+            c = sc.certificate_list[0]
             text.append(urwid.Text([("head", "Server Certificate:")]))
             parts = [
                 ("Type", "%s, %s bits" % c.keyinfo),
-                ("SHA1 digest", c.digest("sha1")),
+                ("SHA256 digest", c.fingerprint().hex(' ')),
                 ("Valid to", str(c.notafter)),
                 ("Valid from", str(c.notbefore)),
                 ("Serial", str(c.serial)),
-                (
-                    "Subject",
-                    urwid.BoxAdapter(
-                        urwid.ListBox(
-                            common.format_keyvals(
-                                c.subject,
-                                key_format="highlight"
-                            )
-                        ),
-                        len(c.subject)
-                    )
-                ),
-                (
-                    "Issuer",
-                    urwid.BoxAdapter(
-                        urwid.ListBox(
-                            common.format_keyvals(
-                                c.issuer,
-                                key_format="highlight"
-                            )
-                        ),
-                        len(c.issuer)
-                    )
-                )
+                ("Subject", urwid.Pile(common.format_keyvals(c.subject, key_format="highlight"))),
+                ("Issuer", urwid.Pile(common.format_keyvals(c.issuer, key_format="highlight")))
             ]
 
             if c.altnames:
-                parts.append(
-                    (
-                        "Alt names",
-                        ", ".join(strutils.bytes_to_escaped_str(x) for x in c.altnames)
-                    )
-                )
+                parts.append(("Alt names", ", ".join(c.altnames)))
             text.extend(
                 common.format_keyvals(parts, indent=4)
             )
@@ -93,7 +82,7 @@ def flowdetails(state, flow: http.HTTPFlow):
         text.append(urwid.Text([("head", "Client Connection:")]))
 
         parts = [
-            ("Address", "{}:{}".format(cc.address[0], cc.address[1])),
+            ("Address", human.format_address(cc.peername)),
         ]
         if req:
             parts.append(("HTTP Version", req.http_version))
@@ -101,10 +90,10 @@ def flowdetails(state, flow: http.HTTPFlow):
             parts.append(("TLS Version", cc.tls_version))
         if cc.sni:
             parts.append(("Server Name Indication", cc.sni))
-        if cc.cipher_name:
-            parts.append(("Cipher Name", cc.cipher_name))
-        if cc.alpn_proto_negotiated:
-            parts.append(("ALPN", cc.alpn_proto_negotiated))
+        if cc.cipher:
+            parts.append(("Cipher Name", cc.cipher))
+        if cc.alpn:
+            parts.append(("ALPN", strutils.bytes_to_escaped_str(cc.alpn)))
 
         text.extend(
             common.format_keyvals(parts, indent=4)
@@ -126,6 +115,12 @@ def flowdetails(state, flow: http.HTTPFlow):
                     maybe_timestamp(cc, "timestamp_tls_setup")
                 )
             )
+        parts.append(
+            (
+                "Client conn. closed",
+                maybe_timestamp(cc, "timestamp_end")
+            )
+        )
 
     if sc is not None and sc.timestamp_start:
         parts.append(
@@ -147,6 +142,12 @@ def flowdetails(state, flow: http.HTTPFlow):
                     maybe_timestamp(sc, "timestamp_tls_setup")
                 )
             )
+        parts.append(
+            (
+                "Server conn. closed",
+                maybe_timestamp(sc, "timestamp_end")
+            )
+        )
 
     if req is not None and req.timestamp_start:
         parts.append(
