@@ -142,6 +142,7 @@ class OptionListWalker(urwid.ListWalker):
         self.index = index
         self.focus_obj = self._get(self.index, self.editing)
         option_focus_change.send(opt.help)
+        self._modified()
 
     def get_next(self, pos):
         if pos >= len(self.opts) - 1:
@@ -155,6 +156,12 @@ class OptionListWalker(urwid.ListWalker):
             return None, None
         return self._get(pos, False), pos
 
+    def positions(self, reverse=False):
+        if reverse:
+            return reversed(range(len(self.opts)))
+        else:
+            return range(len(self.opts))
+
 
 class OptionsList(urwid.ListBox):
     def __init__(self, master):
